@@ -12,31 +12,6 @@
 #' @param color the color scale. By default, "white", "#F8DAC5FF", "#F4825AFF", "#D2204CFF", and "#771F59FF".
 #'
 #' @returns list of densities, plot, and priorities
-#'
-#' @examples
-#' # Density 1: Distance from Mosul
-#' dist_from_mosul <- get_dist_focus(window = iraq_window,
-#'                                   lon = c(43.158),
-#'                                   lat = c(36.349),
-#'                                   resolution = 0.5,
-#'                                   mile = FALSE,
-#'                                   preprocess = FALSE)
-#'
-#' # Density 2: Distance from Baghdad
-#' dist_from_baghd <- get_dist_focus(window = iraq_window,
-#'                                   lon = c(44.366),
-#'                                   lat = c(33.315),
-#'                                   resolution = 0.5,
-#'                                   mile = FALSE,
-#'                                   preprocess = FALSE)
-#'
-#' # Simulation
-#' sim_power_dens(target_dens = list(dist_from_baghd),
-#'                dens_manip = dist_from_mosul,
-#'                priorities = 1,
-#'                priorities_manip = c(1, 2, 5, 10, 15, 50),
-#'                window = iraq_window,
-#'                grayscale = FALSE)
 
 sim_power_dens <- function(target_dens, #This must be a list element
                            dens_manip,
@@ -61,14 +36,14 @@ sim_power_dens <- function(target_dens, #This must be a list element
 
   for (jj in 1:length(priorities_manip)){
     temp <- power_density * dens_manip ^ priorities_manip[jj]
-    temp <- temp/spatstat.geom::integral(temp, domain = window)
+    temp <- temp/spatstat.univar::integral(temp, domain = window)
     power_density_list[[jj]] <- temp
   }
 
   power_density_list <- lapply(1:length(priorities_manip),
                                function(x) {
                                  temp <- power_density * dens_manip ^ priorities_manip[x]
-                                 temp <- temp/spatstat.geom::integral(temp, domain = window)
+                                 temp <- temp/spatstat.univar::integral(temp, domain = window)
                                  return(temp)
                                }
                                )
